@@ -28,7 +28,8 @@ class SendGrid(object):
             "email": {  # emails of recipient list
                 "add": "/api/newsletter/lists/email/add.json",
                 "edit": "/api/newsletter/lists/email/edit.json",
-                "get": "/api/newsletter/lists/email/get.json"},
+                "get": "/api/newsletter/lists/email/get.json",
+                "del": "/api/newsletter/lists/email/delete.json"},
             "recipients": {  # recipients for a newsletter
                 "add": "/api/newsletter/recipients/add.json",
                 "get": "/api/newsletter/recipients/get.json"},
@@ -130,6 +131,10 @@ class SendGrid(object):
     def add_email_to(self, **fields):
         return self.call('email', 'add', dict(**fields))
 
+    def del_email_from(self, **fields):
+        '''fields can be list, and email'''
+        return self.call('email', 'del', dict(**fields))
+
     def add_emails_to(self, list_name, emails):
         """adds a list of emails
         [{'email': 'jon@jon.com', 'name': 'Jon'}, {'email': 'mary@mary.com', 'name': 'Mary'}]
